# SCOS Save Utility for Python 3

## What is this?

This utility is used for enabling access to `.ini` files to get a save like experience.

Using this is easy and fast, that even somebody who doesn't know Python really well can use this.
